Property Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

A |
| activeTheme, $.jqplot.ThemeEngine
| alignTicks, $.jqplot.LinearAxisRenderer
| alpha, $.jqplot.shadowRenderer
| angle $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.shadowRenderer
| animate, jqPlot
| animateReplot, jqPlot
| autoscale, Axis
| autoscaleBubbles, $.jqplot.BubbleRenderer
| autoscaleMultiplier, $.jqplot.BubbleRenderer
| autoscalePointsFactor, $.jqplot.BubbleRenderer
| axes, jqPlot
| axesDefaults, jqPlot
| axisDefaults, $.jqplot.LogAxisRenderer
B |
| background $.jqplot.MeterGaugeRenderer Grid Legend
| bandData, $.jqplot.LineRenderer
| barDirection, $.jqplot.BarRenderer
| barLabelOptions, $.jqplot.MekkoAxisRenderer
| barLabelRenderer, $.jqplot.MekkoAxisRenderer
| barLabels, $.jqplot.MekkoAxisRenderer
| barMargin, $.jqplot.BarRenderer
| barPadding Global$.jqplot.BarRenderer
| barWidth, $.jqplot.BarRenderer
| baselineColor Global$.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer
| baselineWidth Global$.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer
| bodyWidth, $.jqplot.OHLCRenderer
| border, Legend
| borderColor $.jqplot.MekkoRenderer Axis Grid
| borderWidth Axis Grid
| breakOnNull, Series
| breakPoints, $.jqplot.LinearAxisRenderer
| breakTickLabel, $.jqplot.LinearAxisRenderer
| bringSeriesToFront, $.jqplot.Highlighter
| bubbleAlpha, $.jqplot.BubbleRenderer
| bubbleGradients, $.jqplot.BubbleRenderer
C |
| candleStick, $.jqplot.OHLCRenderer
| clearRect, $.jqplot.shapeRenderer
| clickReset, $.jqplot.Cursor
| closeColor, $.jqplot.OHLCRenderer
| color $.jqplot.CanvasOverlay$.jqplot.Dragable$.jqplot.LineRenderer$.jqplot.MarkerRenderer$.jqplot.Trendline Series
| constrainOutsideZoom, $.jqplot.Cursor
| constrainSmoothing, $.jqplot.LineRenderer
| constrainTo, $.jqplot.Dragable
| constrainZoomTo, $.jqplot.Cursor
| css, $.jqplot.BlockRenderer
| cursorLegendFormatString, $.jqplot.Cursor

> this.activeTheme=null

Pointer to currently active theme

> this.alignTicks = false

true to align tick marks across opposed axes such as from the y2axis to yaxis.

> this.alpha = 0.07

alpha transparency of shadow stroke.

> this.angle = 0

angle of text, measured clockwise from x axis.

> this.angle = 0

angle of text, measured clockwise from x axis.

> this.angle = 45

Angle of the shadow in degrees.

> this.animate = false

True to animate the series on initial plot draw (renderer dependent).

> this.animateReplot = false

True to animate series after a call to the replot() method.

> this.autoscale = false

DEPRECATED the default scaling algorithm produces superior results.

> this.autoscaleBubbles = true

True to scale the bubble radius based on plot size.

> this.autoscaleMultiplier = 1.0

Multiplier the bubble size if autoscaleBubbles is true.

> this.autoscalePointsFactor = -0.07

Factor which decreases bubble size based on how many bubbles on on the chart.

> this.axes = {xaxis: new Axis('xaxis'), yaxis: new Axis('yaxis'), x2axis: new Axis('x2axis'), y2axis: new Axis('y2axis'), y3axis: new Axis('y3axis'), y4axis: new Axis('y4axis'), y5axis: new Axis('y5axis'), y6axis: new Axis('y6axis'), y7axis: new Axis('y7axis'), y8axis: new Axis('y8axis'), y9axis: new Axis('y9axis'), yMidAxis: new Axis('yMidAxis')}

up to 4 axes are supported, each with its own options, See Axis for axis specific options.
default options that will be applied to all axes.
Default properties which will be applied directly to the series.

> this.background = "#efefef"

background color of the inside of the gauge.

> this.background = '#fffdf6'

css spec for the background color.

> this.background

css spec for the background of the legend box.

> this.renderer.bandData = []

Data used to draw error bands or confidence intervals above/below a line.

> this.barDirection = 'vertical'

‘vertical’ = up and down bars, ‘horizontal’ = side to side bars

> this.barLabelOptions = {}

options object to pass to the bar label renderer.

> this.barLabelRenderer = $.jqplot.AxisLabelRenderer

renderer to use to draw labels under each bar.

> this.barLabels = this.barLabels || []

array of labels to put under each bar.

> this.barMargin = 10

Number of pixels between groups of bars at adjacent axis values.

> this.barPadding = 10

> this.barPadding = 8

Number of pixels between adjacent bars at the same axis value.

> this.barWidth = null

Width of the bar in pixels (auto by devaul).

> this.baselineColor = null

CSS color spec for the baseline.

> this.baselineColor = null

CSS color spec for the baseline.

> this.baselineColor = null

CSS color spec for the baseline.

> this.baselineWidth = null

width of the baseline in pixels.

> this.baselineWidth = null

width of the baseline in pixels.

> this.baselineWidth = null

width of the baseline in pixels.

> this.bodyWidth = 'auto'

width of the candlestick body in pixels.

> this.border

css spec for the border around the legend box.

> this.borderColor = null

color of the borders between areas on the chart

> this.borderColor = null

color of the border adjacent to the axis.

> this.borderColor = '#999999'

css spec for the color of the grid border.

> this.borderWidth = null

width of line stroked at the border of the axis.

> this.borderWidth = 2.0

width of the border in pixels.

> this.breakOnNull = false

Wether line segments should be be broken at null value.

> this.breakPoints = null

EXPERIMENTAL!!

> this.breakTickLabel = "&asymp

Label to use at the axis break if breakPoints are specified.

> this.bringSeriesToFront = false

This option requires jQuery 1.4+ True to bring the series of the highlighted point to the front of other series.

> this.bubbleAlpha = 1.0

Alpha transparency to apply to all bubbles in this series.

> this.bubbleGradients = false

True to color the bubbles with gradient fills instead of flat colors.

> this.candleStick = false

true to render chart as candleStick.

> this.clearRect = false

true to cear a rectangle.

> this.clickReset = false

Will reset plot zoom if single click on plot without drag.

> this.closeColor = null

color of the close price tick mark.
color of the line

> this.color

CSS color spec for the dragged point (and adjacent line segment or bar).
color of lines at top and bottom of bands [default: series color].

> this.color = '#666666'

color of marker.

> this.color = '#666666'

CSS color spec for the trend line.

> this.color

css color spec for the series

> this.constrainOutsideZoom = true

True to limit actual zoom area to edges of grid, even when zooming outside of plot area.

> this.renderer.constrainSmoothing = true

True to use a more accurate smoothing algorithm that will not overshoot any data points.

> this.constrainTo = 'none'

Constrain dragging motion to an axis or to none.

> this.constrainZoomTo = 'none'

‘none’, ‘x’ or ‘y’

> this.css = {padding:'2px', border:'1px solid #999', textAlign:'center'}

default css styles that will be applied to all data blocks.

> this.cursorLegendFormatString = $.jqplot.Cursor.cursorLegendFormatString

Format string used in the cursor legend.
Close